@@ -3,6 +3,8 @@ import lenstronomy.ImSim.de_lens as de_lens
 from lenstronomy.Util import util
 import numpy as np
 
+__all__ = ['ImageLinearFit']
+
 
 class ImageLinearFit(ImageModel):
     """
@@ -271,20 +273,20 @@ class ImageLinearFit(ImageModel):
             image = source_light_response[i]
             image *= extinction
             image = self.ImageNumerics.re_size_convolve(image, unconvolved=unconvolved)
-            A[n, :] = self.image2array_masked(image)
+            A[n, :] = np.nan_to_num(self.image2array_masked(image), copy=False)
             n += 1
         # response of lens light profile
         for i in range(0, n_lens_light):
             image = lens_light_response[i]
             image = self.ImageNumerics.re_size_convolve(image, unconvolved=unconvolved)
-            A[n, :] = self.image2array_masked(image)
+            A[n, :] = np.nan_to_num(self.image2array_masked(image), copy=False)
             n += 1
         # response of point sources
         for i in range(0, n_points):
             image = self.ImageNumerics.point_source_rendering(ra_pos[i], dec_pos[i], amp[i])
-            A[n, :] = self.image2array_masked(image)
+            A[n, :] = np.nan_to_num(self.image2array_masked(image), copy=False)
             n += 1
-        return np.nan_to_num(A)
+        return A
 
     def update_linear_kwargs(self, param, kwargs_lens, kwargs_source, kwargs_lens_light, kwargs_ps):
         """
