@@ -5,6 +5,8 @@ from scipy.integrate import quad
 from lenstronomy.LensModel.Profiles.base_profile import LensProfileBase
 from lenstronomy.Util import derivative_util as calc_util
 
+__all__ = ['CoredDensity2']
+
 
 class CoredDensity2(LensProfileBase):
     """
@@ -13,10 +15,12 @@ class CoredDensity2(LensProfileBase):
 
     .. math::
 
-        \rho(r) = 2/\pi * \Sigma_{\rm crit} R_c^2 * (R_c^2 + r^2)^{-3/2}
+      \rho(r) = 2/\pi * \Sigma_{\rm crit} R_c^2 * (R_c^2 + r^2)^{-3/2}
+
+    This profile drops like an NFW profile as math:`\rho(r)^{-3}`.
 
-    This profile drops as math:`\rho(r)^{-3}` like an NFW profile.
     """
+
     model_name = 'CORED_DENSITY_2'
     _s = 0.000001  # numerical limit for minimal radius
     param_names = ['sigma0', 'r_core', 'center_x', 'center_y']
