@@ -1,6 +1,7 @@
 __author__ = 'sibirrer'
 
 import pytest
+import numpy as np
 import numpy.testing as npt
 import unittest
 from lenstronomy.LightModel.light_param import LightParam
@@ -12,7 +13,8 @@ class TestParam(object):
         self.light_model_list = ['GAUSSIAN', 'MULTI_GAUSSIAN', 'SERSIC', 'SERSIC_ELLIPSE',
                                  'CORE_SERSIC', 'SHAPELETS', 'HERNQUIST',
                                  'HERNQUIST_ELLIPSE', 'PJAFFE', 'PJAFFE_ELLIPSE', 'UNIFORM',
-                                 'SHAPELETS', 'SHAPELETS_POLAR_EXP'
+                                 'SHAPELETS', 'SHAPELETS_POLAR_EXP',
+                                 'SLIT_STARLETS',
                                  ]
         self.kwargs = [
             {'amp': 1., 'sigma': 1, 'center_x': 0, 'center_y': 0},  # 'GAUSSIAN'
@@ -29,35 +31,38 @@ class TestParam(object):
             {'amp': 1},  # 'UNIFORM'
             {'amp': [1], 'beta': 1, 'n_max': 0, 'center_x': 0, 'center_y': 0},  # 'SHAPELETS'
             {'amp': [1], 'beta': 1, 'n_max': 0, 'center_x': 0, 'center_y': 0},  # 'SHAPELETS_POLAR_EXP'
-
-
+            {'amp': np.ones((3*20**2,)), 'n_scales': 3, 'n_pixels': 20**2, 'scale': 0.05, 'center_x': 0, 'center_y': 0},  # 'SLIT_STARLETS'
         ]
-        self.kwargs_sigma = [
-            {'amp_sigma': 1., 'sigma_sigma': 1, 'center_x_sigma': 0, 'center_y_sigma': 0},
-            # 'GAUSSIAN'
-            {'amp_sigma': [1., 1.], 'sigma_sigma': [1, 1], 'center_x_sigma': 0, 'center_y_sigma': 0},
-            # 'MULTI_GAUSSIAN'
-            {'amp_sigma': 1, 'R_sersic_sigma': 0.5, 'n_sersic_sigma': 1, 'center_x_sigma': 1, 'center_y_sigma': 1},  # 'SERSIC'
-            {'amp_sigma': 1, 'R_sersic_sigma': 0.5, 'n_sersic_sigma': 1, 'center_x_sigma': 1,
-             'center_y_sigma': 1, 'e1_sigma': 0.1, 'e2_sigma': 0.1},  # 'SERSIC_ELLIPSE'
-            {'amp_sigma': 1, 'R_sersic_sigma': 0.5, 'n_sersic_sigma': 1, 'center_x_sigma': 1,
-             'center_y_sigma': 1, 'e1_sigma': 0.1, 'e2_sigma': 0.1, 'Re_sigma': 0.01, 'gamma_sigma': 0.1},  # 'CORE_SERSIC'
-            {'amp_sigma': [1, 1, 1], 'beta_sigma': 0.1, 'n_max_sigma': 1, 'center_x_sigma': 0, 'center_y_sigma': 0},  # 'SHAPELETS'
-            {'amp_sigma': 1, 'Rs_sigma': 0.5, 'center_x_sigma': 0, 'center_y_sigma': 0},  # 'HERNQUIST'
-            {'amp_sigma': 1, 'Rs_sigma': 0.5, 'center_x_sigma': 0, 'center_y_sigma': 0, 'e1_sigma': 0.1, 'e2_sigma': 0.1},  # 'HERNQUIST_ELLIPSE'
-            {'amp_sigma': 1, 'Ra_sigma': 0.1, 'Rs_sigma': 0.5, 'center_x_sigma': 0, 'center_y_sigma': 0},  # 'PJAFFE'
-            {'amp_sigma': 1, 'Ra_sigma': 0.1, 'Rs_sigma': 0.5, 'center_x_sigma': 0, 'center_y_sigma': 0, 'e1_sigma': 0.1, 'e2_sigma': 0.1},  # 'PJAFFE'
-            {'amp_sigma': 0.1},  # 'UNIFORM'
-
+        # self.kwargs_sigma = [
+        #     {'amp_sigma': 1., 'sigma_sigma': 1, 'center_x_sigma': 0, 'center_y_sigma': 0},
+        #     # 'GAUSSIAN'
+        #     {'amp_sigma': [1., 1.], 'sigma_sigma': [1, 1], 'center_x_sigma': 0, 'center_y_sigma': 0},
+        #     # 'MULTI_GAUSSIAN'
+        #     {'amp_sigma': 1, 'R_sersic_sigma': 0.5, 'n_sersic_sigma': 1, 'center_x_sigma': 1, 'center_y_sigma': 1},  # 'SERSIC'
+        #     {'amp_sigma': 1, 'R_sersic_sigma': 0.5, 'n_sersic_sigma': 1, 'center_x_sigma': 1,
+        #      'center_y_sigma': 1, 'e1_sigma': 0.1, 'e2_sigma': 0.1},  # 'SERSIC_ELLIPSE'
+        #     {'amp_sigma': 1, 'R_sersic_sigma': 0.5, 'n_sersic_sigma': 1, 'center_x_sigma': 1,
+        #      'center_y_sigma': 1, 'e1_sigma': 0.1, 'e2_sigma': 0.1, 'Re_sigma': 0.01, 'gamma_sigma': 0.1},  # 'CORE_SERSIC'
+        #     {'amp_sigma': [1, 1, 1], 'beta_sigma': 0.1, 'n_max_sigma': 1, 'center_x_sigma': 0, 'center_y_sigma': 0},  # 'SHAPELETS'
+        #     {'amp_sigma': 1, 'Rs_sigma': 0.5, 'center_x_sigma': 0, 'center_y_sigma': 0},  # 'HERNQUIST'
+        #     {'amp_sigma': 1, 'Rs_sigma': 0.5, 'center_x_sigma': 0, 'center_y_sigma': 0, 'e1_sigma': 0.1, 'e2_sigma': 0.1},  # 'HERNQUIST_ELLIPSE'
+        #     {'amp_sigma': 1, 'Ra_sigma': 0.1, 'Rs_sigma': 0.5, 'center_x_sigma': 0, 'center_y_sigma': 0},  # 'PJAFFE'
+        #     {'amp_sigma': 1, 'Ra_sigma': 0.1, 'Rs_sigma': 0.5, 'center_x_sigma': 0, 'center_y_sigma': 0, 'e1_sigma': 0.1, 'e2_sigma': 0.1},  # 'PJAFFE'
+        #     {'amp_sigma': 0.1},  # 'UNIFORM'
+        # ]
+        self.kwargs_fixed = [
+            {}, {'sigma': [1, 3]}, {}, {}, {}, {'n_max': 1}, {}, {}, {}, {}, {}, {'n_max': 0}, {'n_max': 0}, 
+            {'n_scales': 3, 'n_pixels': 20**2, 'scale': 0.05, 'center_x': 0, 'center_y': 0},
         ]
-        self.kwargs_fixed = [{}, {'sigma': [1, 3]}, {}, {}, {}, {'n_max': 1}, {}, {}, {}, {}, {}, {'n_max': 0}, {'n_max': 0}
-                             ]
-        self.kwargs_fixed_linear = [{}, {'sigma': [1, 3]}, {}, {}, {}, {'n_max': 1}, {}, {}, {}, {}, {}, {}, {}]
-        self.kwargs_mean = []
-        for i in range(len(self.light_model_list)):
-            kwargs_mean_k = self.kwargs[i].copy()
-            #kwargs_mean_k.update(self.kwargs_sigma[i])
-            self.kwargs_mean.append(kwargs_mean_k)
+        self.kwargs_fixed_linear = [
+            {}, {'sigma': [1, 3]}, {}, {}, {}, {'n_max': 1}, {}, {}, {}, {}, {}, {}, {},
+            {'n_scales': 3, 'n_pixels': 20**2, 'scale': 0.05, 'center_x': 0, 'center_y': 0},
+        ]
+        # self.kwargs_mean = []
+        # for i in range(len(self.light_model_list)):
+        #     kwargs_mean_k = self.kwargs[i].copy()
+        #     #kwargs_mean_k.update(self.kwargs_sigma[i])
+        #     self.kwargs_mean.append(kwargs_mean_k)
         self.param = LightParam(light_model_list=self.light_model_list,
                                kwargs_fixed=self.kwargs_fixed, type='source_light', linear_solver=False)
         self.param_linear = LightParam(light_model_list=self.light_model_list,
@@ -86,7 +91,7 @@ class TestParam(object):
 
     def test_num_params(self):
         num, list = self.param.num_param()
-        assert num == 66
+        assert num == (66+1200)
 
     def test_param_name_list(self):
         param_name_list = self.param.param_name_list
@@ -94,13 +99,16 @@ class TestParam(object):
 
     def test_num_param_linear(self):
 
-        kwargs_fixed = [{}, {'sigma': [1, 3]}, {}, {}, {}, {'n_max': 1}, {}, {},
-                             {}, {}, {}, {'n_max': 0}, {'n_max': 0}]
+        kwargs_fixed = [
+            {}, {'sigma': [1, 3]}, {}, {}, {}, {'n_max': 1}, {}, {},
+            {}, {}, {}, {'n_max': 0}, {'n_max': 0},
+            {'n_scales': 3, 'n_pixels': 20**2, 'scale': 0.05, 'center_x': 0, 'center_y': 0},
+        ]
         param = LightParam(light_model_list=self.light_model_list,
                                 kwargs_fixed=kwargs_fixed, type='source_light', linear_solver=True)
 
         num = param.num_param_linear()
-        assert num == 16
+        assert num == (16+1200)
 
 
 class TestRaise(unittest.TestCase):
@@ -120,6 +128,21 @@ class TestRaise(unittest.TestCase):
         with self.assertRaises(ValueError):
             lighModel = LightParam(light_model_list=['MULTI_GAUSSIAN'], kwargs_fixed=[{}], linear_solver=False)
             lighModel.getParams(args=[1, 1, 1, 1], i=0)
+        with self.assertRaises(ValueError):
+            lighModel = LightParam(light_model_list=['SLIT_STARLETS'], kwargs_fixed=[{}], linear_solver=False)
+            lighModel.getParams(args=[1], i=0)
+        with self.assertRaises(ValueError):
+            # no fixed params provided 
+            lighModel = LightParam(light_model_list=['SLIT_STARLETS'], kwargs_fixed=[{}], linear_solver=False)
+            lighModel.setParams(kwargs_list=[{'amp': np.ones((3*20**2))}])
+        with self.assertRaises(ValueError):
+            # missing fixed params
+            lighModel = LightParam(light_model_list=['SLIT_STARLETS'], kwargs_fixed=[{'n_scales': 3}], linear_solver=False)
+            lighModel.setParams(kwargs_list=[{'amp': np.ones((3*20**2))}])
+        with self.assertRaises(ValueError):
+            # missing fixed params
+            lighModel = LightParam(light_model_list=['SLIT_STARLETS'], kwargs_fixed=[{'n_scales': 3}], linear_solver=False)
+            lighModel.num_param()
 
 
 if __name__ == '__main__':
